@@ -8,6 +8,7 @@ ERR_NOMOTD      = "422"
 RPL_UMODEIS     = "221"
 RPL_VISIBLEHOST = "396"
 RPL_TRYAGAIN    = "263"
+RPL_YOUREOPER          = "381"
 
 ERR_NOSUCHNICK   = "401"
 ERR_NOSUCHSERVER = "402"
@@ -76,3 +77,6 @@ ERR_THROTTLE       = "480"
 
 RPL_LOGOFF     = "601"
 RPL_MONOFFLINE = "731"
+
+RPL_RSACHALLENGE2      = "740"
+RPL_ENDOFRSACHALLENGE2 = "741"
