@@ -9,7 +9,9 @@ class User(object):
         self.hostname: Optional[str] = None
         self.realname: Optional[str] = None
         self.account:  Optional[str] = None
+        self.server:   Optional[str] = None
         self.away:     Optional[str] = None
+        self.ip:       Optional[str] = None
         self.channels: Set[str]      = set([])
 
     def __repr__(self) -> str:
